@@ -1,12 +1,12 @@
 import sys,click
 
 @click.command()
-@click.option('-x', '--xmindpath', 'config', required=True, help='xmind file path')
-@click.option('-e', '--excelpath', 'config', required=True, help='excel file path')
-@click.option('-i', '--ignorelayer', 'config', is_flag=True, default='0')
+@click.option('-x', '--xmindpath', 'xmindpath', required=True, help='xmind file path')
+@click.option('-e', '--excelpath', 'excelpath', required=True, help='excel file path')
+@click.option('-i', '--ignorelayer', 'ignorelayer', is_flag=True, default='0')
 # @click.option('--pretty', 'pretty', is_flag=True, default=False, help='pretty print json')
-def main(xmindPath, excelPath, ignorelayer):
-    test(xmindPath, excelPath, ignorelayer)
+def main(xmindpath, excelpath, ignorelayer):
+    test(xmindpath, excelpath, ignorelayer)
 
 
 def test(xmindPath, excelPath, ignorelayer):
